@@ -19,8 +19,8 @@ nyc <- read_gtfs(local_gtfs_path,
                  frequency=TRUE)
 
 ## ------------------------------------------------------------------------
-routes_df_frequencies <- nyc$routes_df %>% 
-  inner_join(nyc$routes_frequency_df, by = "route_id") %>% 
+routes_df_frequencies <- nyc$routes %>% 
+  inner_join(nyc$routes_frequency, by = "route_id") %>% 
           select(route_long_name,
                  median_headways, 
                  mean_headways, 
@@ -30,25 +30,25 @@ head(routes_df_frequencies)
 
 ## ------------------------------------------------------------------------
 routes_sf_frequencies <- nyc$routes_sf %>% 
-      inner_join(nyc$routes_frequency_df, by = "route_id") %>% 
+      inner_join(nyc$routes_frequency, by = "route_id") %>% 
           select(median_headways, 
                  mean_headways, 
                  st_dev_headways, 
                  stop_count)
-plot(routes_sf_frequencies)
 
 ## ------------------------------------------------------------------------
-head(sample_n(nyc$calendar_df,10))
+head(sample_n(nyc$calendar,10))
 
 ## ------------------------------------------------------------------------
-select_service_id <- filter(nyc$calendar_df,monday==1) %>% pull(service_id)
-select_route_id <- sample_n(nyc$routes_df,1) %>% pull(route_id)
+select_service_id <- filter(nyc$calendar, monday==1) %>% pull(service_id)
+select_route_id <- filter(nyc$routes,route_id=="C")
 
 ## ------------------------------------------------------------------------
-some_trips <- nyc$trips_df %>%
-  filter(route_id %in% select_route_id & service_id %in% select_service_id)
+some_trips <- nyc$trips %>%
+  filter(route_id %in% select_route_id & 
+           service_id %in% select_service_id)
 
-some_stop_times <- nyc$stop_times_df %>% 
+some_stop_times <- nyc$stop_times %>% 
   filter(trip_id %in% some_trips$trip_id) 
 
 some_stops <- nyc$stops_sf %>%
@@ -56,7 +56,14 @@ some_stops <- nyc$stops_sf %>%
 
 ## ------------------------------------------------------------------------
 some_stops_freq_sf <- some_stops %>%
-  left_join(nyc$stops_frequency_df, by="stop_id") %>%
+  left_join(nyc$stops_frequency, by="stop_id") %>%
   select(headway)
 plot(some_stops_freq_sf)
 
+## ------------------------------------------------------------------------
+some_stops_freq_sf <- some_stops %>%
+  left_join(nyc$stops_frequency, by="stop_id") %>%
+  select(headway) %>%
+  filter(headway<100)
+plot(some_stops_freq_sf)
+
